summaryrefslogtreecommitdiff
path: root/gdb/charset.c
diff options
context:
space:
mode:
authorJim Meyering <meyering@redhat.com>2009-10-08 08:50:51 +0000
committerJim Meyering <meyering@redhat.com>2009-10-08 08:58:19 +0000
commit79b5a82e464c9ec7731ed6f80580ceb13f745168 (patch)
treee258911599426e00b8bc17b4e491a583c9d88027 /gdb/charset.c
parentf699d949b3eb15dfba4284d326934d5163fc444b (diff)
downloadgdb-79b5a82e464c9ec7731ed6f80580ceb13f745168.tar.gz
manually sync from the CVS repository
Diffstat (limited to 'gdb/charset.c')
-rw-r--r--gdb/charset.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/gdb/charset.c b/gdb/charset.c
index a59d9c65d33..f5281eda169 100644
--- a/gdb/charset.c
+++ b/gdb/charset.c
@@ -102,17 +102,17 @@
iconv_t
iconv_open (const char *to, const char *from)
{
/* We allow conversions from UCS-4BE, wchar_t, and the host charset.
We allow conversions to wchar_t and the host charset. */
- if (strcmp (from, "UCS-4BE") && strcmp (from, "wchar_t")
+ if (strcmp (from, "UTF-32BE") && strcmp (from, "wchar_t")
&& strcmp (from, GDB_DEFAULT_HOST_CHARSET))
return -1;
if (strcmp (to, "wchar_t") && strcmp (to, GDB_DEFAULT_HOST_CHARSET))
return -1;
/* Return 1 if we are converting from UCS-4BE, 0 otherwise. This is
used as a flag in calls to iconv. */
- return !strcmp (from, "UCS-4BE");
+ return !strcmp (from, "UTF-32BE");
}
int
@@ -122,10 +122,10 @@ iconv_close (iconv_t arg)
}
size_t
-iconv (iconv_t ucs_flag, const char **inbuf, size_t *inbytesleft,
+iconv (iconv_t utf_flag, const char **inbuf, size_t *inbytesleft,
char **outbuf, size_t *outbytesleft)
{
- if (ucs_flag)
+ if (utf_flag)
{
while (*inbytesleft >= 4)
{
@@ -193,7 +193,7 @@ iconv (iconv_t ucs_flag, const char **inbuf, size_t *inbytesleft,
#endif
#ifndef GDB_DEFAULT_TARGET_WIDE_CHARSET
-#define GDB_DEFAULT_TARGET_WIDE_CHARSET "UCS-4"
+#define GDB_DEFAULT_TARGET_WIDE_CHARSET "UTF-32"
#endif
static const char *auto_host_charset_name = GDB_DEFAULT_HOST_CHARSET;
@@ -102,17 +102,17 @@
iconv_open (const char *to, const char *from)
{
- /* We allow conversions from UCS-4BE, wchar_t, and the host charset.
+ /* We allow conversions from UTF-32BE, wchar_t, and the host charset.
We allow conversions to wchar_t and the host charset. */
@@ -102,17 +102,17 @@
if (strcmp (to, "wchar_t") && strcmp (to, GDB_DEFAULT_HOST_CHARSET))
return -1;
- /* Return 1 if we are converting from UCS-4BE, 0 otherwise. This is
+ /* Return 1 if we are converting from UTF-32BE, 0 otherwise. This is
used as a flag in calls to iconv. */